@@ -1,10 +1,12 @@
 package CGI::Pretty;
 
 use strict;
+use warnings;
+
 use if $] >= 5.019, 'deprecate';
 use CGI ();
 
-$CGI::Pretty::VERSION = '4.26';
+$CGI::Pretty::VERSION = '4.38';
 $CGI::DefaultClass = __PACKAGE__;
 @CGI::Pretty::ISA = qw( CGI );
 
@@ -62,10 +64,6 @@ the "pretty" functions will no longer output "pretty" HTML.
 
 L<HTML::HTML5::Parser> + L<HTML::HTML5::Writer> + L<XML::LibXML::PrettyPrint>:
 
-    use HTML::HTML5::Parser qw();
-    use HTML::HTML5::Writer qw();
-    use XML::LibXML::PrettyPrint qw();
-
     print HTML::HTML5::Writer->new(
         start_tags => 'force',
         end_tags   => 'force',
